/*
 * @file
 * Javascript for showing and hiding dependent attributes.
 *
 * Retrieves the dependencies from the database using a callback and shows
 * and hides attributes depending upon the value selected for the attribute
 * they depend upon.
 */

(function ($) {

  Drupal.behaviors.uc_dropdown_attributes = {
    attach: function (context, settings) {
      basePath = Drupal.settings.basePath;
      if (settings.uc_dropdown_attributes.cleanUrl==0) {
        basePath = basePath + '?q=';
      }
      // Product carts.
      $('div.add-to-cart').each( function(i,val) {
        if ($(val).find('fieldset').length) {
          // Product kit.
          $(val).find('fieldset').each( function(i,val) {
            var attributes = $(val).find('div.attributes');
            if (attributes.length!=0) {
              var nid = $(val).attr('id').split('-')[2];
              attributeBind(attributes, nid);
            }
          });
        }
        else {
          // Product
          var attributes = $(val).find('div.attributes');
          if (attributes.length!=0) {
            var nid = $(val).find('form').attr('id').split('-')[6];
            attributeBind(attributes, nid);
          }
        }
      });
    }
  };

  var attributeBind = function(attributes, nid) {
   $(attributes).find('div.attribute').each( function(i,attribute) {
     var aidClasses = $(attribute).attr('class').split(' ');
     $(aidClasses).each (function(i, val) {
       var aidClass = val.split('-');
       if (aidClass[0]=='attribute' && aidClass[1]!=undefined) {
         var aid = aidClass[1];
         var type = getAttributeType(attribute, aid);
         var classes;
         switch(type) {
         case 'select':
           classes = $(attribute).find('select.form-select').attr('class')
                                 .split(' ');
           break;
         case 'radio':
           classes = $(attribute).find('div.form-radios').attr('class')
                                 .split(' ');
           break;
         case 'checkbox':
           classes = $(attribute).find('div.form-checkboxes').attr('class')
                                 .split(' ');
           break;
         case 'text':
           classes = $(attribute).find('input.form-text').attr('class')
                                 .split(' ');
           break;
         }
         var parent_aid;
         $(classes).each (function(i, val) {
           var aClass = val.split('-');
           if (aClass[0] == 'parent') {
             parent_aid = aClass[1];
           }
         });
         if (parent_aid != undefined) {
           var id = getID(attribute, type);
           var parentAttribute = $(attributes)
             .find('div.attribute-' + parent_aid);
           var parentType = getAttributeType(parentAttribute, parent_aid);
           var parent_id = getID(parentAttribute, parentType);
           $('#' + parent_id).change(function() {
             $.get(basePath + 'node/' + nid + '/dependencies/' + id +
                   '/dependency/' + parent_id, null, applyAttribute);
           });
         }
       }
      });
    });
  };
  
  var applyAttribute = function(response) {
    if (response.status) {
      var parentType = getType(response.parent_id);
      var values;
      switch(parentType) {
      case 'select':
        values = [];
        value = $('#' + response.parent_id).val();
        if (value !== '') {
            values.push(value);
        }
        break;
      case 'radio':
        value = $('#' + response.parent_id).find('input:checked').val();
        values = [value];
        break;
      case 'checkbox':
        values = [];
        $.each($('#' + response.parent_id).find('input:checkbox:checked'),
          function() {
            values.push($(this).val());
          }
        );
        break;
      default:
        break;
      }
      var type = getType(response.id);
      switch(type) {
      case 'select':
      case 'radio':
      case 'checkbox':
      case 'text':
        if (intersection(values, response.parent_values)) {
          if (response.required == 1) {
            var label =
              $('#' + response.id).parent().find('label').not('.option');
            if (label.find('span').length==0) {
              $(label).replaceWith('<label>' + $(label).text() +
                '<span class="form-required" title="' +
                Drupal.t('This field is required.') + '">*</span></label>');
            }
          }
          $('#' + response.id).parent().css('display', 'block');
        }
        else {
          $('#' + response.id).parent().css('display', 'none');
          switch(type) {
          case 'select':
            $('#' + response.id).find('option').attr('selected', false);
            break;
          case 'radio':
            $('#' + response.id).find('input:radio').attr('checked', false);
            break;
          case 'checkbox':
            $('#' + response.id).find('input:checkbox').attr('checked', false);
            break;
          case 'text':
            $('#' + response.id).val('');
            break;
          }
          $('#' + response.id).trigger('change');
        }
        break;
      }
    }
  };

  var getType = function(id) {
    type = $('#' + id).find('input').attr('type');
    if (type=='radio' || type=='checkbox') {
      return type;
    }
    type = $('#' + id).attr('type');
    if (type=='text') {
      return type;
    }
    return 'select';
  };

  var getAttributeType = function(attribute, aid) {
    type = $(attribute).find('input[name*="attributes[' + aid + ']"]')
      .attr('type');
    if (type=='radio' || type=='text' || type=='checkbox') {
      return type;
    }
    type = $(attribute).find('input[name*="[attributes][' + aid + ']"]')
      .attr('type');
    if (type=='radio' || type=='text' || type=='checkbox') {
      return type;
    }
    return 'select';
  };

  var getID = function(attribute, type) {
    var id;
    switch(type) {
    case 'select':
      id = $(attribute).find('select.form-select').attr('id');
      break;
    case 'radio':
      id = $(attribute).find('div.form-radios').attr('id');
      break;
    case 'checkbox':
      id = $(attribute).find('div.form-checkboxes').attr('id');
      break;
    case 'text':
      id = $(attribute).find('input.form-text').attr('id');
      break;
    }
    return id;
  }

  var intersection = function(array, object) {
    for (var i=0; i<array.length; i++) {
      if (object[array[i]] != undefined) {
        return true;
      }
    }
    return false;
  };

})(jQuery);
